#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
import glob
import logging
import os
import re
import sys
from pathlib import Path

from vela.forger import forge

"""
Emulate a CASA run
"""


class CasaEmulator:
    def __init__(self, metadata: str, ppr: str, product_type: str):
        self.logger = logging.getLogger("vela")
        self.ppr = ppr
        self.metadata = metadata
        self.product_type = product_type

    def run(self):
        self.logger.info("Vela waiting on the Forger....")
        forge(self.metadata, self.product_type)
        self.check_logs()

    def check_logs(self):
        if self.product_type == "restore":
            self.logger.info("CHECKING VELA LOGS!")

            if not os.getcwd().endswith("/working"):
                os.chdir("./working")

            vela_logs = glob.glob("vela-*.log")

            for file in vela_logs:
                content = Path(file).read_text()
                errors = re.search(r".*SEVERE\s*flagmanager.*", content)
                self.logger.info(errors)
                if errors:
                    self.logger.info("VELA ERROR! Please inspect logs.")
                    os.chdir("../")
                    sys.exit(1)

        self.logger.info("VELA processing complete.")
