"""fix calibration PPR to match CIPL

Revision ID: b858cc90549c
Revises: 452f9923d108
Create Date: 2022-03-14 13:53:36.811913

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "b858cc90549c"
down_revision = "452f9923d108"
branch_labels = None
depends_on = None

new_ppr = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<ns2:SciPipeRequest xmlns:ns2="Common/pipelinescience/SciPipeRequest">
    <ProjectSummary>
        <ProposalCode>VLA/null</ProposalCode>
        <Observatory>NRAO</Observatory>
        <Telescope>VLA</Telescope>
        <ProcessingSite>Socorro</ProcessingSite>
        <Operator>vlapipe</Operator>
        <Mode>SCIENCE</Mode>
        <Version>NGRH-ALMA-10_8</Version>
        <CreationTime>{{created_at}}</CreationTime>
    </ProjectSummary>
    <ProjectStructure>TBD</ProjectStructure>
    <ProcessingRequests>
        <RootDirectory>{{root_directory}}</RootDirectory>
        <ProcessingRequest>
            <ProcessingIntents>
                <Intents>
                    <Keyword>VLA_INTERFEROMETRY_STANDARD_OBSERVING_MODE</Keyword>
                    <Value>Undefined</Value>
                </Intents>
            </ProcessingIntents>
            <ProcessingProcedure>
                <ProcedureTitle>hifv_cal</ProcedureTitle>
                <ProcessingCommand>
                    <Command>hifv_importdata</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_hanning</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_flagdata</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>hm_tbuff</Keyword>
                            <Value>1.5int</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword>fracspw</Keyword>
                            <Value>0.01</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword>intents</Keyword>
                            <Value>*POINTING*,*FOCUS*,*ATMOSPHERE*,*SIDEBAND_RATIO*, *UNKNOWN*, *SYSTEM_CONFIGURATION*, *UNSPECIFIED#UNSPECIFIED*</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_vlasetjy</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_priorcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_testBPdcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_checkflag</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>checkflagmode</Keyword>
                            <Value>bpd-vla</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_semiFinalBPdcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_checkflag</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>checkflagmode</Keyword>
                            <Value>allcals-vla</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_solint</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_fluxboot</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_finalcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_applycals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_checkflag</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>checkflagmode</Keyword>
                            <Value>target-vla</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_targetflag</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>intents</Keyword>
                            <Value>*TARGET*</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_statwt</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_plotsummary</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hif_makeimlist</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>intent</Keyword>
                            <Value>PHASE,BANDPASS</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword>specmode</Keyword>
                            <Value>cont</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hif_makeimages</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>hm_masking</Keyword>
                            <Value>centralregion</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_exportdata</Command>
                    <ParameterSet/>
                </ProcessingCommand>
            </ProcessingProcedure>
            <DataSet>
                <RelativePath>{{relative_path}}</RelativePath>
                <SdmIdentifier>{{sdmId}}</SdmIdentifier>
                <DataType>asdm</DataType>
            </DataSet>
        </ProcessingRequest>
    </ProcessingRequests>
    <ResultsProcessing>
        <ArchiveResults>false</ArchiveResults>
        <CleanUpDisk>false</CleanUpDisk>
        <UpdateProjectLifeCycle>false</UpdateProjectLifeCycle>
        <NotifyOperatorWhenDone>false</NotifyOperatorWhenDone>
        <SDMall>false</SDMall>
        <SDMonly>false</SDMonly>
        <PipelineOperatorAddress>Unknown</PipelineOperatorAddress>
    </ResultsProcessing>
</ns2:SciPipeRequest>

"""

old_ppr = """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<ns2:SciPipeRequest xmlns:ns2="Common/pipelinescience/SciPipeRequest">
    <ProjectSummary>
        <ProposalCode>VLA/null</ProposalCode>
        <Observatory>NRAO</Observatory>
        <Telescope>VLA</Telescope>
        <ProcessingSite>Socorro</ProcessingSite>
        <Operator>vlapipe</Operator>
        <Mode>SCIENCE</Mode>
        <Version>NGRH-ALMA-10_8</Version>
        <CreationTime>{{created_at}}</CreationTime>
    </ProjectSummary>
    <ProjectStructure>TBD</ProjectStructure>
    <ProcessingRequests>
        <RootDirectory>{{root_directory}}</RootDirectory>
        <ProcessingRequest>
            <ProcessingIntents>
                <Intents>
                    <Keyword>VLA_INTERFEROMETRY_STANDARD_OBSERVING_MODE</Keyword>
                    <Value>Undefined</Value>
                </Intents>
            </ProcessingIntents>
            <ProcessingProcedure>
                <ProcedureTitle>hifv_cal</ProcedureTitle>
                <ProcessingCommand>
                    <Command>hifv_importdata</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_hanning</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_flagdata</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>hm_tbuff</Keyword>
                            <Value>1.5int</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword>intents</Keyword>
                            <Value>*POINTING*,*FOCUS*,*ATMOSPHERE*,*SIDEBAND_RATIO*, *UNKNOWN*, *SYSTEM_CONFIGURATION*, *UNSPECIFIED#UNSPECIFIED*</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_vlasetjy</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_priorcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_testBPdcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_checkflag</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_semiFinalBPdcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_checkflag</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>checkflagmode</Keyword>
                            <Value>semi</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_semiFinalBPdcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_solint</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_fluxboot</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_finalcals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_applycals</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_targetflag</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>intents</Keyword>
                            <Value>*CALIBRATE*,*TARGET*</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_statwt</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_plotsummary</Command>
                    <ParameterSet/>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hif_makeimlist</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>intent</Keyword>
                            <Value>PHASE,BANDPASS</Value>
                        </Parameter>
                        <Parameter>
                            <Keyword>specmode</Keyword>
                            <Value>cont</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hif_makeimages</Command>
                    <ParameterSet>
                        <Parameter>
                            <Keyword>hm_masking</Keyword>
                            <Value>none</Value>
                        </Parameter>
                    </ParameterSet>
                </ProcessingCommand>
                <ProcessingCommand>
                    <Command>hifv_exportdata</Command>
                    <ParameterSet/>
                </ProcessingCommand>
            </ProcessingProcedure>
            <DataSet>
                <RelativePath>{{relative_path}}</RelativePath>
                <SdmIdentifier>{{sdmId}}</SdmIdentifier>
                <DataType>asdm</DataType>
            </DataSet>
        </ProcessingRequest>
    </ProcessingRequests>
    <ResultsProcessing>
        <ArchiveResults>false</ArchiveResults>
        <CleanUpDisk>false</CleanUpDisk>
        <UpdateProjectLifeCycle>false</UpdateProjectLifeCycle>
        <NotifyOperatorWhenDone>false</NotifyOperatorWhenDone>
        <SDMall>false</SDMall>
        <SDMonly>false</SDMonly>
        <PipelineOperatorAddress>Unknown</PipelineOperatorAddress>
    </ResultsProcessing>
</ns2:SciPipeRequest>
"""


def upgrade():
    op.execute(
        f"""
        UPDATE capability_templates
        SET content=E'{new_ppr}' 
        WHERE filename='PPR.xml' AND capability_name='std_calibration'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE capability_templates
        SET content=E'{old_ppr}' 
        WHERE filename='PPR.xml' AND capability_name='std_calibration'
        """
    )
