# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""restore corrections

Revision ID: fd68d858d354
Revises: 87dae5acfd34
Create Date: 2021-07-20 10:45:50.997748

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "fd68d858d354"
down_revision = "87dae5acfd34"
branch_labels = None
depends_on = None


restore_condor_content = """executable = restore_cms.sh
arguments = {{product_locator}} {{cal_locator}} {{request_id}} metadata.json PPR.xml

output = restore.out
error = restore.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, $(SBIN_PATH)/deliver, ./PPR.xml, ./metadata.json
transfer_output_files = working, rawdata, products, delivery.json

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue


"""

restore_img_content = """executable = std_restore_imaging.sh
arguments = {{product_locator}} {{cal_product_locator}} {{request_id}} metadata.json PPR.xml

output = restore.out
error = restore.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, $(SBIN_PATH)/deliver, ./PPR.xml, ./metadata.json
transfer_output_files = working, rawdata, products, delivery.json

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue


"""


old_restore_img = """executable = std_restore_imaging.sh
arguments = {{product_locator}} {{cal_product_locator}} {{request_id}} metadata.json PPR.xml

output = restore.out
error = restore.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, $(SBIN_PATH)/deliver, ./PPR.xml, ./metadata.json
transfer_output_files = working, rawdata, products

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue


"""

old_restore_condor = """executable = restore_cms.sh
arguments = {{product_locator}} {{cal_locator}} {{request_id}} metadata.json PPR.xml

output = restore.out
error = restore.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, $(SBIN_PATH)/deliver, ./PPR.xml, ./metadata.json
transfer_output_files = working, rawdata, products

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue


"""


def upgrade():
    op.execute(
        """
        UPDATE capabilities
        SET capability_steps='prepare-and-run-workflow restore_cms\nawait-workflow'
        WHERE capability_name='restore_cms'
        """
    )
    op.execute(
        """
        UPDATE capabilities
        SET capability_steps='prepare-and-run-workflow std_restore_imaging\nawait-workflow'
        WHERE capability_name='std_restore_imaging'
        """
    )

    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{restore_condor_content}' WHERE filename='restore_cms.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{restore_img_content}' WHERE filename='std_restore_imaging.condor'
        """
    )


def downgrade():
    op.execute(
        """
        UPDATE capabilities
        SET capability_steps='prepare-and-run-workflow restore_cms\nawait-workflow\nawait-qa'
        WHERE capability_name='restore_cms'
        """
    )
    op.execute(
        """
        UPDATE capabilities
        SET capability_steps='prepare-and-run-workflow std_restore_imaging\nawait-workflow\nawait-qa'
        WHERE capability_name='std_restore_imaging'
        """
    )

    op.execute(
        f"""
        UPDATE workflow_templates
        SET content=E'{old_restore_condor}' WHERE filename='restore_cms.condor'
        """
    )
    op.execute(
        f"""
            UPDATE workflow_templates
            SET content=E'{old_restore_img}' WHERE filename='std_restore_imaging.condor'
            """
    )
